import { DictTextProps } from './types';
import isPromise from 'is-promise';
/**
 * 字典描述显示
 */

export default {
  name: 'EDictText',
  props: DictTextProps,
  data: function data() {
    return {
      // 显示文字
      caption: ''
    };
  },
  mounted: function mounted() {
    this._getDictCaption();
  },
  methods: {
    /**
     * 根据字典组id获取字典列表。此方法需要在Vue.use挂载组件的时候被覆盖
     */
    getDictList: function getDictList() {},

    /**
     * 获取显示的字典值
     * @private
     */
    _getDictCaption: function _getDictCaption() {
      var _this = this;

      var result = this.getDictList(this.$props.dictId);

      if (isPromise(result)) {
        result.then(function (res) {
          var dictObj = res.find(function (item) {
            return item.name === _this.$props.name;
          });
          _this.$data.caption = dictObj ? dictObj.caption : _this.$props.name;
        })["catch"](function () {
          _this.$data.caption = _this.$props.defaultValue;
        });
      } else {
        this.$data.caption = this.$props.defaultValue;
      }
    }
  },
  render: function render() {
    var h = arguments[0];
    var caption = this.$data.caption;
    return h("span", [caption]);
  }
};