function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import { AbstractStepProps } from './types';
import EForm from '../Form';
import AButton from 'ant-design-vue/es/button';
/**
 * 分步表单抽象类,分步组件的其中每一步必须从这个继承,如新增商户的页面其中的每一个step，需要从这个继承
 */

export default {
  name: 'EAbstractStep',
  props: AbstractStepProps,
  data: function data() {
    return {
      // 高级表单中表单域来源
      // 使用data中的fieldList则设置为true，使用computed中的computedFieldList则为false
      // 一般业务比较简单，固定的表单域则可以用data中的fieldList；业务比较复杂，由多个可变因素决定，则需要用到computedFieldList
      fieldUseData: true,
      // 表单字段
      fieldList: [],
      // formData下节点的key,如该表单的默认值仅为一个大的bean中的嵌套bean，那么则可以根据key来获取
      dataChildName: null,
      // 不可编辑的key列表
      disabledKeyList: []
    };
  },
  computed: {
    // 表单域，如果要生效，则data中的fieldUseData需要设置成false
    computedFieldList: function computedFieldList() {
      return null;
    },
    // 计算后的表单域，根据fieldUseData来判断
    advancedFieldList: function advancedFieldList() {
      if (this.fieldUseData) {
        return this.fieldList;
      }

      return this.computedFieldList;
    },
    // 表单的默认值
    form: function form() {
      if (this.dataChildName) {
        return this.formData[this.dataChildName] || {};
      }

      return this.formData;
    }
  },
  created: function created() {
    // 解构表单接口数据到表单内部私有数据
    this._parseFormData(this.$props.formData);
  },
  methods: {
    // 保存草稿，无需检验表单填写
    // _saveDraft () {
    //   this.$refs.ruleForm.getValue()
    // },

    /**
     * 表单变动，内部调用
     * @param key 键
     * @param value 值
     * @param label 名称
     * @param form 整个form
     * @private
     */
    _formValueChange: function _formValueChange(_ref) {
      var key = _ref.key,
          value = _ref.value,
          label = _ref.label,
          form = _ref.form;

      // 存在方法则调用
      if (this["_".concat(key, "Change")]) {
        this["_".concat(key, "Change")](form, value, label);
      } else if (this._needEmitChange(key)) {
        // 是否需要向父元素发送change事件
        this.$emit('change', key, value);
      }
    },

    /**
     *  是否需要向父元素发送change事件，该方法可覆盖
     * @param key 键
     * @returns {boolean}
     * @private
     */
    // eslint-disable-next-line no-unused-vars
    _needEmitChange: function _needEmitChange(key) {
      return false;
    },
    // _emitChange(key, value) {
    //   this.$emit('change', key, value)
    // },

    /**
     * 将传入的formData属性解构成高级表单内部对象，建议数据嵌套不要太深（最好一级）。如将3个嵌套bean合成的一个大的bean，解构成一个仅仅和当前步骤相关的小的bean
     * 此方法可被覆盖。也可以覆盖解析出步骤页面需要的私有属性
     */
    // eslint-disable-next-line no-unused-vars
    _parseFormData: function _parseFormData(formData) {// this.form = formData
    },

    /**
     * 上一步
     * @private
     */
    _previewStep: function _previewStep() {
      this.$emit('previewStep');
    },

    /**
     * 下一步，需要检验表单填写
     * @private
     */
    _nextStep: function _nextStep() {
      var _this = this;

      this.$refs.ruleForm.validate().then(function () {
        _this.$emit('nextStep');
      })["catch"](function (error) {
        console.log('error submit!!' + error.message);
      });
    },

    /**
     * 将高级表单校验后的数据拼接成期望结构的业务数据
     * 此方法可被覆盖
     */
    _getValidFormData: function _getValidFormData(form) {
      if (this.dataChildName) {
        return _defineProperty({}, this.dataChildName, form);
      }

      return form;
    },

    /**
     * 获取表单数据
     * 可供外部调用
     */
    getFormData: function getFormData() {
      return this._getValidFormData(this.$refs.ruleForm.getValue());
    },

    /**
     * 重置表单，外部调用
     */
    reset: function reset() {
      this.$refs.ruleForm.reset();
    },

    /**
     * 重置校验结果
     */
    clearValidate: function clearValidate() {
      this.$refs.ruleForm.clearValidate();
    }
  },
  render: function render() {
    var h = arguments[0];
    var _this$$props = this.$props,
        labelSpan = _this$$props.labelSpan,
        isOnlyUpdatePhoto = _this$$props.isOnlyUpdatePhoto,
        index = _this$$props.index,
        nextText = _this$$props.nextText,
        nextLoading = _this$$props.nextLoading;
    return h(EForm, {
      ref: "ruleForm",
      attrs: {
        labelSpan: labelSpan,
        list: this.advancedFieldList,
        formData: this.form,
        isOnlyEditUpload: isOnlyUpdatePhoto,
        disabledKeyList: this.disabledKeyList
      },
      on: {
        "change": this._formValueChange
      }
    }, [h("slot", {
      slot: "footer"
    }, [index === 0 ? null : h(AButton, {
      attrs: {
        type: "primary",
        ghost: true
      },
      style: "marginRight:16px;",
      on: {
        "click": this._previewStep
      }
    }, ["\u4E0A\u4E00\u6B65"]), h(AButton, {
      attrs: {
        type: "primary",
        loading: nextLoading
      },
      on: {
        "click": this._nextStep
      }
    }, [nextText || '下一步'])])]);
  }
};